@@ -11,16 +11,25 @@
 // WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 // See the License for the specific language governing permissions and
 // limitations under the License.
+//
 
-// +build !go1.12
+// +build go1.12
 
 package main
 
 import (
+	"fmt"
 	"log"
+	"runtime/debug"
 )
 
 func printVersion() {
-	log.Printf("No version information is available for Mockgen compiled with " +
-		"version 1.11")
+	if bi, exists := debug.ReadBuildInfo(); exists {
+		fmt.Println(bi.Main.Version)
+	} else {
+		log.Printf("No version information found. Make sure to use " +
+			"GO111MODULE=on when running 'go get' in order to use specific " +
+			"version of the binary.")
+	}
+
 }
